@@ -22,10 +22,18 @@ import strings
 import wx
 import wx.html as html
 
-
+## June 25th 2016
+## Remarking these two lines because they are causing a segfault:
+##  ../src/common/stdpbase.cpp(62): assert "traits" failed in Get(): 
+##  create wxApp before calling this
+##  Segmentation fault (core dumped)
+##
+##  I do not know how to test or fix this, hence simply removing it.
+##  AFAICT, stock buttons will be in the system language.
+##
 ## Setup wxPython to access translations : enables the stock buttons.
-langid = wx.LANGUAGE_DEFAULT # Picks this up from $LANG
-mylocale = wx.Locale( langid )
+##langid = wx.LANGUAGE_DEFAULT # Picks this up from $LANG
+##mylocale = wx.Locale( langid )
 
 ## langcode = locale.getlocale()[0] # I must not use getlocale...
 ## This is suggested by Martin:
