@@ -750,7 +750,11 @@ class Pog(BasicFontList):
 			PogEmpty
 			PogAllFontsFailedToInstall
 			PogSomeFontsDidNotInstall
+			NoFontsDir
 		"""	
+		if not os.path.exists(self.__pc.userFontPath()):
+			raise fontybugs.NoFontsDir("Missing .fonts dir")
+
 		def linkfont(fi, frompaf, topaf):
 			## 15 Sept 2009 : Catch situations where the font is already installed.
 			try:
