@@ -17,9 +17,18 @@
 
 import wx, locale
 
+## June 25th 2016
+## Remarking these two lines because they are causing a segfault:
+##  ../src/common/stdpbase.cpp(62): assert "traits" failed in Get(): 
+##  create wxApp before calling this
+##  Segmentation fault (core dumped)
+##
+##  I do not know how to test or fix this, hence simply removing it.
+##  AFAICT, stock buttons will be in the system language.
+##
 ## Setup wxPython to access translations : enables the stock buttons.
-langid = wx.LANGUAGE_DEFAULT # Picks this up from $LANG
-mylocale = wx.Locale( langid )
+##langid = wx.LANGUAGE_DEFAULT # Picks this up from $LANG
+##mylocale = wx.Locale( langid )
 
 from pubsub import *
 from wxgui import ps
@@ -203,6 +212,10 @@ class PogChooser(wx.ListCtrl) :
 			li = wx.ListItem() 
 			li.SetImage(i) 
 			li.SetText(p) 
+
+			## June 25, 2016: Something in wxPython changed and li now needs an Id>0
+			li.Id = 1
+
 			id = wx.NewId()
 			PogChooser.__poglistCopy[id] = p # record the pog name
 			row = self.InsertItem( li ) 
